@@ -204,7 +204,6 @@ public:
         , mWorkingHoursYTop(0)
         , mWorkingHoursYBottom(0)
         , mHasSelection(false)
-        , mSelectedId(QChar(-1))
         , mMarcusBains(nullptr)
         , mActionType(Agenda::NOP)
         , mItemMoved(false)
@@ -407,7 +406,6 @@ void Agenda::init()
     d->mItemMoved = false;
 
     d->mSelectedItem = nullptr;
-    d->mSelectedId = QChar(-1);
 
     setAcceptDrops(true);
     installEventFilter(this);
@@ -582,7 +580,11 @@ bool Agenda::eventFilter_drag(QObject *obj, QDropEvent *de)
         de->setDropAction(Qt::MoveAction);
 
         QWidget *dropTarget = qobject_cast<QWidget *>(obj);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         QPoint dropPosition = de->pos();
+#else
+        QPoint dropPosition = de->position().toPoint();
+#endif
         if (dropTarget && dropTarget != this) {
             dropPosition = dropTarget->mapTo(this, dropPosition);
         }
@@ -1205,7 +1207,7 @@ void Agenda::endItemAction()
 
                     d->mAgendaView->enableAgendaUpdate(true);
                 } else {
-                    KMessageBox::sorry(this,
+                    KMessageBox::error(this,
                                        i18n("Unable to add the exception item to the calendar. "
                                             "No change will be done."),
                                        i18n("Error Occurred"));
